.. _lino:

====================
The ``lino`` package
====================

The ``lino`` package is the core package of every :term:`Lino application`.

.. py2rst::

  from lino import SETUP_INFO
  print(SETUP_INFO['long_description'])
